==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/config_wizard/translations/config_wizard_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Aby zastosować zmiany języka Kadu musi zostać uruchomione ponownie</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Tworzenie konta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Chcę dodać istniejące konto</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Chcę zarejestrować nowe konto</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Nie chcę teraz dodawać konta</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Wybierz sieć w której chcesz skonfigurować konto.&lt;/p&gt;&lt;p&gt;Kreator konfiguracji pozwala także na stworzenie nowego konto&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Konfiguracja zakończona&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Przejdź do okna konfiguracji kont po zamknięciu tego okna</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Potwierdź wprowadzone ustawienia aby rozpocząć korzystanie z Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard...</source>
        <translation>Uruchom kreator konfiguracji...</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Witamy w Kadu&lt;/h3&gt;&lt;p&gt;Ten kreator pomoże ci ustawić podstawową konfigurację programu.&lt;/p&gt;&lt;p&gt;Proszę wybrać język i podać swój pseudonim/imię</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Ustawienia profilu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nick</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Tworzenie konta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Wprowadź dane konta.&lt;/p&gt;&lt;p&gt;Cofnij się, jeżeli chcesz wybrać inną opcję ustawień konta.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kreator konfiguracji</translation>
    </message>
</context>
</TS>

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/config_wizard/translations/config_wizard_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Aby zastosować zmiany języka Kadu musi zostać uruchomione ponownie.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Tworzenie konta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Chcę dodać istniejące konto</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Chcę zarejestrować nowe konto</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Nie chcę teraz dodawać konta</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Wybierz sieć w której chcesz skonfigurować konto.&lt;/p&gt;&lt;p&gt;Kreator konfiguracji pozwala także na stworzenie nowego konto&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Konfiguracja zakończona&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Przejdź do okna konfiguracji kont po zamknięciu tego okna</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Potwierdź wprowadzone ustawienia aby rozpocząć korzystanie z Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard...</source>
        <translation>Uruchom kreator konfiguracji...</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Witamy w Kadu&lt;/h3&gt;&lt;p&gt;Ten kreator pomoże ci ustawić podstawową konfigurację programu.&lt;/p&gt;&lt;p&gt;Proszę wybrać język i podać swój pseudonim/imię</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Ustawienia profilu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nick</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Tworzenie konta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Wprowadź dane konta.&lt;/p&gt;&lt;p&gt;Cofnij się, jeżeli chcesz wybrać inną opcję ustawień konta.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kreator konfiguracji</translation>
    </message>
</context>
</TS>
